Module: RestDSL::DSLExtensions
- Defined in:
- lib/rest_dsl/dsl.rb
Overview
A collection of DSL extensions for use with various worlds to allow the use of some simpler dsl language in them.
For rspec, in spec helper add config.extend RestDSL::DSLExtensions::<
Defined Under Namespace
Modules: FromFile